@@ -37,11 +37,11 @@ def to_docker_camel(string):
             "oom_killed": "OOMKilled",
             "rw": "RW",
             "link_local_ipv6_address": "LinkLocalIPv6Address",
-            "link_local_ipv6_prefix_lenght": "LinkLocalIPv6PrefixLen",
+            "link_local_ipv6_prefix_length": "LinkLocalIPv6PrefixLen",
             "secondary_ipv6_addresses": "SecondaryIPv6Addresses",
             "endpoint_id": "EndpointID",
-            "global_ipv6_prefix_lenght": "GlobalIPv6PrefixLen",
-            "ip_prefix_lenght": "IPPrefixLen",
+            "global_ipv6_prefix_length": "GlobalIPv6PrefixLen",
+            "ip_prefix_length": "IPPrefixLen",
             "ipv6_gateway": "IPv6Gateway",
             "network_id": "NetworkID",
             "ip_address": "IPAddress",
